@@ -10,12 +10,12 @@ Usage::
     client: AugmentedAIRuntimeClient = boto3.client("sagemaker-a2i-runtime")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_sagemaker_a2i_runtime.literals import ListHumanLoopsPaginatorName, SortOrder
 from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
 from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
     DescribeHumanLoopResponseTypeDef,
@@ -25,12 +25,6 @@ from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
     StartHumanLoopResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("AugmentedAIRuntimeClient",)
 
 
@@ -54,7 +48,7 @@ class Exceptions:
 
 class AugmentedAIRuntimeClient:
     """
-    [AugmentedAIRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
+    [AugmentedAIRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
     """
 
     meta: ClientMeta
@@ -62,17 +56,17 @@ class AugmentedAIRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
         """
 
     def delete_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Client.delete_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
+        [Client.delete_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
         """
 
     def describe_human_loop(self, HumanLoopName: str) -> DescribeHumanLoopResponseTypeDef:
         """
-        [Client.describe_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
+        [Client.describe_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
         """
 
     def generate_presigned_url(
@@ -83,7 +77,7 @@ class AugmentedAIRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
         """
 
     def list_human_loops(
@@ -91,12 +85,12 @@ class AugmentedAIRuntimeClient:
         FlowDefinitionArn: str,
         CreationTimeAfter: datetime = None,
         CreationTimeBefore: datetime = None,
-        SortOrder: Literal["Ascending", "Descending"] = None,
+        SortOrder: SortOrder = None,
         NextToken: str = None,
         MaxResults: int = None,
     ) -> ListHumanLoopsResponseTypeDef:
         """
-        [Client.list_human_loops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
+        [Client.list_human_loops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
         """
 
     def start_human_loop(
@@ -107,15 +101,15 @@ class AugmentedAIRuntimeClient:
         DataAttributes: HumanLoopDataAttributesTypeDef = None,
     ) -> StartHumanLoopResponseTypeDef:
         """
-        [Client.start_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
+        [Client.start_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
         """
 
     def stop_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
+        [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
         """
 
-    def get_paginator(self, operation_name: Literal["list_human_loops"]) -> ListHumanLoopsPaginator:
+    def get_paginator(self, operation_name: ListHumanLoopsPaginatorName) -> ListHumanLoopsPaginator:
         """
-        [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+        [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
         """
