@@ -13,10 +13,8 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_sagemaker_a2i_runtime.literals import ContentClassifier, HumanLoopStatus
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -49,7 +47,7 @@ HumanLoopSummaryTypeDef = TypedDict(
     "HumanLoopSummaryTypeDef",
     {
         "HumanLoopName": str,
-        "HumanLoopStatus": Literal["InProgress", "Failed", "Completed", "Stopped", "Stopping"],
+        "HumanLoopStatus": HumanLoopStatus,
         "CreationTime": datetime,
         "FailureReason": str,
         "FlowDefinitionArn": str,
@@ -72,7 +70,7 @@ _RequiredDescribeHumanLoopResponseTypeDef = TypedDict(
     "_RequiredDescribeHumanLoopResponseTypeDef",
     {
         "CreationTime": datetime,
-        "HumanLoopStatus": Literal["InProgress", "Failed", "Completed", "Stopped", "Stopping"],
+        "HumanLoopStatus": HumanLoopStatus,
         "HumanLoopName": str,
         "HumanLoopArn": str,
         "FlowDefinitionArn": str,
@@ -92,12 +90,7 @@ class DescribeHumanLoopResponseTypeDef(
 
 
 HumanLoopDataAttributesTypeDef = TypedDict(
-    "HumanLoopDataAttributesTypeDef",
-    {
-        "ContentClassifiers": List[
-            Literal["FreeOfPersonallyIdentifiableInformation", "FreeOfAdultContent"]
-        ]
-    },
+    "HumanLoopDataAttributesTypeDef", {"ContentClassifiers": List[ContentClassifier]}
 )
 
 HumanLoopInputTypeDef = TypedDict("HumanLoopInputTypeDef", {"InputContent": str})
